
from django.urls import path, include
from django.conf.urls.i18n import i18n_patterns

from flatpages.views import flatpage


app_name = 'flatpages'


urlpatterns = [

    path('<str:url>/', flatpage, name='page')

]


app_urls = i18n_patterns(
    path('page/', include((urlpatterns, app_name)))
)



# -*- coding: utf-8 -

page_meta = [
    {
        'url': 'flatpages:page',
        'title': '{{ flatpage.title }}',
        'title_uk': '{{ flatpage.title }}',
        'title_ru': '{{ flatpage.title }}',
        'title_en': '{{ flatpage.title }}',
        'keywords': '{{ flatpage.title }}',
        'keywords_uk': '{{ flatpage.title }}',
        'keywords_ru': '{{ flatpage.title }}',
        'keywords_en': '{{ flatpage.title }}',
        'description': '{{ flatpage.title }}',
        'description_uk': '{{ flatpage.title }}',
        'description_ru': '{{ flatpage.title }}',
        'description_en': '{{ flatpage.title }}',
        'breadcrumb': '{{ flatpage.title }}',
        'breadcrumb_uk': '{{ flatpage.title }}',
        'breadcrumb_ru': '{{ flatpage.title }}',
        'breadcrumb_en': '{{ flatpage.title }}',
        'header': '{{ flatpage.title }}',
        'header_uk': '{{ flatpage.title }}',
        'header_ru': '{{ flatpage.title }}',
        'header_en': '{{ flatpage.title }}'
    }
]




from django.apps import apps
from django.db import models
from django.contrib import admin

from modeltranslation.admin import TranslationAdmin
from modeltranslation.utils import get_translation_fields

from flatpages.forms import FlatpageForm
from flatpages.models import FlatPage


def _get_wising_editor():

    if apps.is_installed('django_prose_editor'):
        from django_prose_editor.widgets import ProseEditorWidget
        return ProseEditorWidget

    if apps.is_installed('ckeditor_uploader'):
        from ckeditor_uploader.widgets import CKEditorUploadingWidget
        return CKEditorUploadingWidget

    if apps.is_installed('ckeditor'):
        from ckeditor.widgets import CKEditorWidget
        return CKEditorWidget

    return None


@admin.register(FlatPage)
class FlatPageAdmin(TranslationAdmin):

    form = FlatpageForm

    list_display = ['url', 'title']

    list_filter = ['registration_required']

    search_fields = ['url', 'title']

    fields = (
        'url',
        tuple(get_translation_fields('title')),
    ) + tuple(get_translation_fields('content')) + (
        ('registration_required', 'template_name', ),
    )

    def __init__(self, *args, **kwargs):

        editor = _get_wising_editor()

        if editor:
            self.formfield_overrides = {
                models.TextField: {
                    'widget': editor
                }
            }

        super().__init__(*args, **kwargs)




from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class FlatPagesConfig(AppConfig):

    name = 'flatpages'
    verbose_name = _("Flat Pages")


default_app_config = 'flatpages.FlatPagesConfig'
